==> SIMDprofiler-0.1.1.tar.gz: SIMDprofiler-0.1.1/setup.py <==
from distutils.core import setup
setup(
  name = 'SIMDprofiler',         # How you named your package folder (MyLib)
  packages = ['SIMDprofiler'],   # Chose the same as "name"
  version = '0.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This is a summarizer for Numba\'s vector report',   # Give a short description about your library
  author = 'Neftali W.',                   # Type in your name
  author_email = 'neftaliw@hotmail.com',      # Type in your E-Mail
  url = 'https://github.com/neftaliw/SIMDprofiler',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/neftaliw/SIMDprofiler/archive/0.1.1.tar.gz',    # I explain this later on
  keywords = ['Numba', 'Vectorization', 'Profiler'],   # Keywords that define your package best
  install_requires=[           
          'numpy',
          'numba',
          'llvmlite',
          'functools'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> SIMDprofiler-0.3.tar.gz: SIMDprofiler-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'SIMDprofiler',         # How you named your package folder (MyLib)
  packages = ['SIMDprofiler'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This is a summarizer for Numba\'s vector report',   # Give a short description about your library
  author = 'Neftali W.',                   # Type in your name
  author_email = 'neftaliw@hotmail.com',      # Type in your E-Mail
  url = 'https://github.com/neftaliw/SIMDprofiler',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/neftaliw/SIMDprofiler/archive/0.3.tar.gz',    # I explain this later on
  keywords = ['Numba', 'Vectorization', 'Profiler'],   # Keywords that define your package best
  install_requires=[           
          'numpy',
          'numba',
          'llvmlite',
          'functools'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
